ReindexedMetric
===============

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ReindexedMetric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ReindexedMetric.increasing
      ~ReindexedMetric.supported_rank_types

   .. rubric:: Methods Summary

   .. autosummary::

      ~ReindexedMetric.expected_value
      ~ReindexedMetric.get_coefficients

   .. rubric:: Attributes Documentation

   .. autoattribute:: increasing
   .. autoattribute:: supported_rank_types

   .. rubric:: Methods Documentation

   .. automethod:: expected_value
   .. automethod:: get_coefficients
